@@ -1,3 +1,4 @@
+from pathlib import Path
 from typing import Generator
 
 from ..tokenization.tokenizer import Tokenizer
@@ -11,7 +12,11 @@ from .text_segment_ref import TextSegmentRef
 class TextFileText(TextBase):
     def __init__(self, word_tokenizer: Tokenizer[str, int, str], id: str, filename: StrPath) -> None:
         super().__init__(word_tokenizer, id, id)
-        self._filename = filename
+        self._filename = Path(filename)
+
+    @property
+    def filename(self) -> Path:
+        return self._filename
 
     def _get_segments(self, include_text: bool) -> Generator[TextSegment, None, None]:
         with open(self._filename, "r", encoding="utf-8-sig") as file:
